@@ -1,4 +1,4 @@
-use crate::filter::Filter;
+use crate::filter::{Filter, FilterError};
 use crate::state::StateManager;
 use crate::ExtractorValue;
 
@@ -19,22 +19,19 @@ impl CountFilter {
 }
 
 impl Filter for CountFilter {
-    fn filter(&mut self, value: &ExtractorValue, _state_manager: &mut StateManager) -> bool {
-        match value {
-            ExtractorValue::None => (),
-            _ => {
-                panic!("Wrong value provided for count filter.");
-            }
-        };
-
+    fn filter(
+        &mut self,
+        _value: &ExtractorValue,
+        _state_manager: &mut StateManager,
+    ) -> Result<bool, FilterError> {
         let current_state = self.state + 1;
         self.state = current_state;
 
         if current_state == self.required_state {
             self.state = 0;
-            true
+            Ok(true)
         } else {
-            false
+            Ok(false)
         }
     }
 }
@@ -43,68 +40,57 @@ impl Filter for CountFilter {
 mod tests {
     use super::*;
 
-    const VALUE_1: u8 = 0xff;
-
     #[test]
-    fn count_filter_initial_zero_maximum_two_test() {
+    fn initial_zero_maximum_two_test() {
         let mut state_manager = StateManager::new();
         let mut filter = CountFilter::new(0, 2);
 
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            false
+            Ok(false)
         );
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            true
+            Ok(true)
         );
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            false
+            Ok(false)
         );
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            true
+            Ok(true)
         );
     }
 
     #[test]
-    fn count_filter_initial_four_maximum_five_test() {
+    fn initial_four_maximum_five_test() {
         let mut state_manager = StateManager::new();
         let mut filter = CountFilter::new(4, 5);
 
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            true
+            Ok(true)
         );
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            false
+            Ok(false)
         );
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            false
+            Ok(false)
         );
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            false
+            Ok(false)
         );
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            false
+            Ok(false)
         );
         assert_eq!(
             filter.filter(&ExtractorValue::None, &mut state_manager),
-            true
+            Ok(true)
         );
     }
-
-    #[test]
-    #[should_panic(expected = "Wrong value provided for count filter.")]
-    fn count_filter_value_has_bad_type_test() {
-        let mut state_manager = StateManager::new();
-        let mut filter = CountFilter::new(0, 5);
-
-        filter.filter(&ExtractorValue::U8(VALUE_1), &mut state_manager);
-    }
 }
